[Bf-blender-cvs] [6b49a9db524] master: Fix T74513: Wrong naming in some Face Set comments and operators

Pablo Dobarro noreply at git.blender.org
Sat Mar 7 16:42:50 CET 2020


Commit: 6b49a9db524968acd5ba0aab2b294ecfbef24ef8
Author: Pablo Dobarro
Date:   Sat Mar 7 00:33:46 2020 +0100
Branches: master
https://developer.blender.org/rB6b49a9db524968acd5ba0aab2b294ecfbef24ef8

Fix T74513: Wrong naming in some Face Set comments and operators

Missing changes from one of the renamings of the initial face sets
patch.

Reviewed By: brecht

Maniphest Tasks: T74513

Differential Revision: https://developer.blender.org/D7054

===================================================================

M	source/blender/editors/sculpt_paint/sculpt.c

===================================================================

diff --git a/source/blender/editors/sculpt_paint/sculpt.c b/source/blender/editors/sculpt_paint/sculpt.c
index c4752d8cd58..41bbaa94904 100644
--- a/source/blender/editors/sculpt_paint/sculpt.c
+++ b/source/blender/editors/sculpt_paint/sculpt.c
@@ -10534,22 +10534,22 @@ static EnumPropertyItem prop_sculpt_face_set_create_types[] = {
         SCULPT_FACE_SET_MASKED,
         "MASKED",
         0,
-        "Face Mask From Masked",
-        "Create a new Face Mask from the masked faces",
+        "Face Set From Masked",
+        "Create a new Face Set from the masked faces",
     },
     {
         SCULPT_FACE_SET_VISIBLE,
         "VISIBLE",
         0,
-        "Face Mask From Visible",
-        "Create a new Face Mask from the visible vertices",
+        "Face Set From Visible",
+        "Create a new Face Set from the visible vertices",
     },
     {
         SCULPT_FACE_SET_ALL,
         "ALL",
         0,
-        "Face Mask Full Mesh",
-        "Create an unique Face Mask with all faces in the sculpt",
+        "Face Set Full Mesh",
+        "Create an unique Face Set with all faces in the sculpt",
     },
     {0, NULL, 0, NULL, NULL},
 };
@@ -10582,7 +10582,7 @@ static int sculpt_face_set_create_invoke(bContext *C, wmOperator *op, const wmEv
     return OPERATOR_CANCELLED;
   }
 
-  SCULPT_undo_push_begin("face mask change");
+  SCULPT_undo_push_begin("face set change");
   SCULPT_undo_push_node(ob, nodes[0], SCULPT_UNDO_FACE_SETS);
 
   const int next_face_set = SCULPT_face_set_next_available_get(ss);
@@ -10626,9 +10626,9 @@ static int sculpt_face_set_create_invoke(bContext *C, wmOperator *op, const wmEv
 static void SCULPT_OT_face_sets_create(wmOperatorType *ot)
 {
   /* identifiers */
-  ot->name = "Create Face Group";
+  ot->name = "Create Face Set";
   ot->idname = "SCULPT_OT_face_sets_create";
-  ot->description = "Create a new Face Group";
+  ot->description = "Create a new Face Set";
 
   /* api callbacks */
   ot->invoke = sculpt_face_set_create_invoke;
@@ -10660,8 +10660,8 @@ static EnumPropertyItem prop_sculpt_face_sets_change_visibility_types[] = {
         SCULPT_FACE_SET_VISIBILITY_SHOW_ACTIVE,
         "SHOW_ACTIVE",
         0,
-        "Show Active Face Mask",
-        "Show Active Face Mask",
+        "Show Active Face Set",
+        "Show Active Face Set",
     },
     {
         SCULPT_FACE_SET_VISIBILITY_HIDE_ACTIVE,
@@ -10674,8 +10674,8 @@ static EnumPropertyItem prop_sculpt_face_sets_change_visibility_types[] = {
         SCULPT_FACE_SET_VISIBILITY_INVERT,
         "INVERT",
         0,
-        "Invert Face Mask Visibility",
-        "Invert Face Mask Visibility",
+        "Invert Face Set Visibility",
+        "Invert Face Set Visibility",
     },
     {
         SCULPT_FACE_SET_VISIBILITY_SHOW_ALL,
@@ -10770,7 +10770,7 @@ static int sculpt_face_sets_change_visibility_invoke(bContext *C,
     SCULPT_face_sets_visibility_invert(ss);
   }
 
   /* Sync face mask visibility and vertex visibility. */
   SCULPT_visibility_sync_all_face_sets_to_vertices(ss);
 
   SCULPT_undo_push_end();
@@ -10800,7 +10800,7 @@ static int sculpt_face_sets_change_visibility_invoke(bContext *C,
 static void SCULPT_OT_face_sets_change_visibility(wmOperatorType *ot)
 {
   /* Identifiers. */
-  ot->name = "Face Mask Visibility";
+  ot->name = "Face Sets Visibility";
   ot->idname = "SCULPT_OT_face_set_change_visibility";
   ot->description = "Change the visibility of the Face Sets of the sculpt";
@@ -10770,7 +10770,7 @@ static int sculpt_face_sets_change_visibility_invoke(bContext *C,
   }
 
-  /* Sync face mask visibility and vertex visibility. */
+  /* Sync face sets visibility and vertex visibility. */
   SCULPT_visibility_sync_all_face_sets_to_vertices(ss);
 



More information about the Bf-blender-cvs mailing list